==> slurm-llnl_2.1.16.orig.tar.bz2: slurm-2.1.16/src/srun/debugger.c <==
/*****************************************************************************\
 *  debugger.c - Definitions needed for parallel debugger
 *  $Id: debugger.c 11149 2007-03-14 20:53:19Z morrone $
 *****************************************************************************
 *  Copyright (C) 2002 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Mark Grondona <grondona1@llnl.gov>, et. al.
 *  CODE-OCEC-09-009. All rights reserved.
 *
 *  This file is part of SLURM, a resource management program.
 *  For details, see <https://computing.llnl.gov/linux/slurm/>.
 *  Please also read the included file: DISCLAIMER.
 *
 *  SLURM is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission
 *  to link the code of portions of this program with the OpenSSL library under
 *  certain conditions as described in each individual source file, and
 *  distribute linked combinations including the two. You must obey the GNU
 *  General Public License in all respects for all of the code used other than
 *  OpenSSL. If you modify file(s) with this exception, you may extend this
 *  exception to your version of the file(s), but you are not obligated to do
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in
 *  the program, then also delete it here.
 *
 *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with SLURM; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\*****************************************************************************/

#if HAVE_CONFIG_H
#  include "config.h"
#endif

#include "src/common/log.h"

#include "src/srun/debugger.h"

/*
 *  Instantiate extern variables from debugger.h
 */
MPIR_PROCDESC *MPIR_proctable;
int MPIR_proctable_size;
VOLATILE int MPIR_debug_state;
VOLATILE int MPIR_debug_gate;
int MPIR_being_debugged;
int MPIR_i_am_starter;
int MPIR_acquired_pre_main;
char *totalview_jobid;

void MPIR_Breakpoint(void)
{
	/*
	 * This just notifies parallel debugger that some event of
	 *  interest occurred.
	 */
	debug("In MPIR_Breakpoint");
}

==> slurm-llnl_2.2.7.orig.tar.bz2: slurm-2.2.7/src/srun/debugger.c <==
/*****************************************************************************\
 *  debugger.c - Definitions needed for parallel debugger
 *  $Id: debugger.c 11149 2007-03-14 20:53:19Z morrone $
 *****************************************************************************
 *  Copyright (C) 2002-2007 The Regents of the University of California.
 *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Mark Grondona <grondona1@llnl.gov>, et. al.
 *  CODE-OCEC-09-009. All rights reserved.
 *
 *  This file is part of SLURM, a resource management program.
 *  For details, see <https://computing.llnl.gov/linux/slurm/>.
 *  Please also read the included file: DISCLAIMER.
 *
 *  SLURM is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission
 *  to link the code of portions of this program with the OpenSSL library under
 *  certain conditions as described in each individual source file, and
 *  distribute linked combinations including the two. You must obey the GNU
 *  General Public License in all respects for all of the code used other than
 *  OpenSSL. If you modify file(s) with this exception, you may extend this
 *  exception to your version of the file(s), but you are not obligated to do
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in
 *  the program, then also delete it here.
 *
 *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with SLURM; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\*****************************************************************************/

#if HAVE_CONFIG_H
#  include "config.h"
#endif

#include "src/common/log.h"

#include "src/srun/debugger.h"
#include "src/srun/srun_job.h"

/*
 *  Instantiate extern variables from debugger.h
 */
MPIR_PROCDESC *MPIR_proctable;
int MPIR_proctable_size;
VOLATILE int MPIR_debug_state;
int MPIR_being_debugged;
int MPIR_i_am_starter;
int MPIR_acquired_pre_main;
char *totalview_jobid;
#ifdef DEBUGGER_PARTIAL_ATTACH
  int MPIR_partial_attach_ok;
#endif

void MPIR_Breakpoint(srun_job_t *job)
{
	/*
	 * This just notifies parallel debugger that some event of
	 *  interest occurred.
	 */
	debug("In MPIR_Breakpoint");
	slurm_step_launch_fwd_signal(job->step_ctx, SIG_DEBUG_WAKE);
}
